@@ -19,7 +19,7 @@ import re
 from collections.abc import Callable, Mapping
 from datetime import datetime, timedelta, timezone
 from typing import TYPE_CHECKING, Any, Final, TypedDict, cast
-from urllib.parse import urlparse
+from urllib.parse import urlencode, urlparse
 
 from streamlit import config
 from streamlit.errors import StreamlitAuthError
@@ -148,6 +148,95 @@ def get_redirect_uri(auth_section: AttrDict) -> str | None:
     return redirect_uri_parsed.geturl()
 
 
+def get_validated_redirect_uri() -> str | None:
+    """Get the redirect_uri from secrets, validating it ends with /oauth2callback.
+
+    This is used for logout flows where we need a validated redirect URI
+    that matches the OAuth callback path.
+
+    Returns
+    -------
+    str | None
+        The validated redirect URI, or None if not configured or invalid.
+    """
+    auth_section = get_secrets_auth_section()
+    if not auth_section:
+        return None
+
+    redirect_uri = get_redirect_uri(auth_section)
+    if not redirect_uri:
+        return None
+
+    if not redirect_uri.endswith("/oauth2callback"):
+        _LOGGER.warning("Redirect URI does not end with /oauth2callback")
+        return None
+
+    return redirect_uri
+
+
+def get_origin_from_redirect_uri() -> str | None:
+    """Extract the origin (scheme + host) from the configured redirect_uri.
+
+    Returns
+    -------
+    str | None
+        The origin in format "scheme://host:port", or None if not configured.
+    """
+    auth_section = get_secrets_auth_section()
+    if not auth_section:
+        return None
+
+    redirect_uri = get_redirect_uri(auth_section)
+    if not redirect_uri:
+        return None
+
+    redirect_uri_parsed = urlparse(redirect_uri)
+    return f"{redirect_uri_parsed.scheme}://{redirect_uri_parsed.netloc}"
+
+
+def build_logout_url(
+    end_session_endpoint: str,
+    client_id: str,
+    post_logout_redirect_uri: str,
+    id_token: str | None = None,
+) -> str:
+    """Build an OIDC logout URL with the required parameters.
+
+    Parameters
+    ----------
+    end_session_endpoint
+        The OIDC provider's end_session_endpoint URL.
+    client_id
+        The OAuth client ID.
+    post_logout_redirect_uri
+        The URI to redirect to after logout.
+    id_token
+        Optional ID token to include as id_token_hint for the logout request.
+
+    Returns
+    -------
+    str
+        The complete logout URL with query parameters.
+    """
+    from urllib.parse import parse_qsl
+
+    logout_params: dict[str, str] = {
+        "client_id": client_id,
+        "post_logout_redirect_uri": post_logout_redirect_uri,
+    }
+
+    if id_token:
+        logout_params["id_token_hint"] = id_token
+
+    # Per OIDC spec, end_session_endpoint should be a clean URL without query params,
+    # but we handle existing params defensively for non-standard providers.
+    parsed = urlparse(end_session_endpoint)
+    existing_params = dict(parse_qsl(parsed.query))
+    merged_params = {**existing_params, **logout_params}
+    new_query = urlencode(merged_params)
+    return parsed._replace(query=new_query).geturl()
+
+
 def encode_provider_token(provider: str) -> str:
     """Returns a signed JWT token with the provider and expiration time."""
     try:
@@ -376,7 +465,7 @@ def get_cookie_with_chunks(
         chunk_name = f"{cookie_name}_{i + 1}"
         chunk_value = get_single_cookie_fn(chunk_name)
         if chunk_value is None:
-            _LOGGER.exception("Missing chunk %d for cookie '%s'", i + 1, cookie_name)
+            _LOGGER.error("Missing chunk %d for cookie '%s'", i + 1, cookie_name)
             return None
         chunks.append(chunk_value)
 
