@@ -26,8 +26,8 @@ from streamlit.runtime.metrics_util import gather_metrics
 if TYPE_CHECKING:
     from collections.abc import Generator, Iterable
 
-_SPACES_RE = re.compile("\\s*")
-_EMPTY_LINE_RE = re.compile("\\s*\n")
+_SPACES_RE = re.compile(r"\s*")
+_EMPTY_LINE_RE = re.compile(r"\s*\n")
 
 
 @gather_metrics("echo")
