@@ -158,7 +158,7 @@ def rerun(  # type: ignore[misc]
 
     """
 
-    if scope not in ["app", "fragment"]:
+    if scope not in {"app", "fragment"}:
         raise StreamlitAPIException(
             f"'{scope}'is not a valid rerun scope. Valid scopes are 'app' and 'fragment'."
         )
