@@ -135,7 +135,9 @@ class BaseSnowflakeConnection(BaseConnection["InternalSnowflakeConnection"]):
             ),
             wait=wait_fixed(1),
         )
-        def _query(sql: str) -> DataFrame:
+        # `params` must be an explicit parameter (not captured from closure) so that
+        # `@st.cache_data` includes it in the cache key.
+        def _query(sql: str, params: Any = None) -> DataFrame:
             cur = self._instance.cursor()
             cur.execute(sql, params=params, **kwargs)
             return cur.fetch_pandas_all()  # type: ignore
@@ -153,7 +155,7 @@ class BaseSnowflakeConnection(BaseConnection["InternalSnowflakeConnection"]):
             ttl=ttl,
         )(_query)
 
-        return _query(sql)
+        return _query(sql, params)
 
     def write_pandas(
         self,
@@ -685,7 +687,7 @@ class SnowflakeCallersRightsConnection(SnowflakeConnection):
     @classmethod
     def _read_token_file(cls) -> str:
         """Returns the contents of the Snowpark token file on disk."""
-        with open(SNOWPARK_CONNECTION_TOKEN_FILE) as token_file:
+        with open(SNOWPARK_CONNECTION_TOKEN_FILE, encoding="utf-8") as token_file:
             return token_file.read()
 
     @classmethod
