@@ -21,12 +21,17 @@ from typing import Any, Final, TypeVar, cast
 import streamlit
 from streamlit import config
 from streamlit.logger import get_logger
+from streamlit.util import calc_md5
 
 _LOGGER: Final = get_logger(__name__)
 
 TFunc = TypeVar("TFunc", bound=Callable[..., Any])
 TObj = TypeVar("TObj", bound=object)
 
+# Set to track which deprecation warnings have been shown (by message hash)
+# when show_once=True is used
+_shown_warnings: set[str] = set()
+
 
 def _error_details_in_browser_enabled() -> bool:
     """True if we should print deprecation warnings to the browser.
@@ -42,7 +47,9 @@ def _error_details_in_browser_enabled() -> bool:
     )
 
 
-def show_deprecation_warning(message: str, show_in_browser: bool = True) -> None:
+def show_deprecation_warning(
+    message: str, show_in_browser: bool = True, show_once: bool = False
+) -> None:
     """Show a deprecation warning message.
 
     Parameters
@@ -55,7 +62,18 @@ def show_deprecation_warning(message: str, show_in_browser: bool = True) -> None
         set `client.showErrorDetails` to "full" or the legacy True value. All
         other values ("stacktrace", "type", "none", False) will hide deprecation
         warnings in the browser (but still log them to the console).
+    show_once : bool, default=False
+        If True, the warning will only be shown once per unique message (based on
+        message hash). Subsequent calls with the same message will be skipped.
+        This is useful for warnings that may be triggered many times during a
+        script run.
     """
+    if show_once:
+        message_hash = calc_md5(message)
+        if message_hash in _shown_warnings:
+            return
+        _shown_warnings.add(message_hash)
+
     if _error_details_in_browser_enabled() and show_in_browser:
         streamlit.warning(message)
 
