@@ -255,7 +255,9 @@ def _determine_data_kind_via_pandas_dtype(
     if pd.api.types.is_object_dtype(
         column_dtype
     ) is False and pd.api.types.is_string_dtype(column_dtype):
-        # The is_string_dtype
+        # This handles pandas 3.0+ StringDtype (and PyArrow-backed string types).
+        # We exclude object dtype here because object columns with string values
+        # are handled via _determine_data_kind_via_inferred_type in the caller.
         return ColumnDataKind.STRING
 
     return ColumnDataKind.UNKNOWN
@@ -289,7 +291,7 @@ def _determine_data_kind_via_inferred_type(
     if inferred_type == "bytes":
         return ColumnDataKind.BYTES
 
-    if inferred_type in ["floating", "mixed-integer-float"]:
+    if inferred_type in {"floating", "mixed-integer-float"}:
         return ColumnDataKind.FLOAT
 
     if inferred_type == "integer":
@@ -304,13 +306,13 @@ def _determine_data_kind_via_inferred_type(
     if inferred_type == "boolean":
         return ColumnDataKind.BOOLEAN
 
-    if inferred_type in ["datetime64", "datetime"]:
+    if inferred_type in {"datetime64", "datetime"}:
         return ColumnDataKind.DATETIME
 
     if inferred_type == "date":
         return ColumnDataKind.DATE
 
-    if inferred_type in ["timedelta64", "timedelta"]:
+    if inferred_type in {"timedelta64", "timedelta"}:
         return ColumnDataKind.TIMEDELTA
 
     if inferred_type == "time":
@@ -411,7 +413,7 @@ ColumnConfigMappingInput: TypeAlias = Mapping[
     # allowing int here leads mypy to complain about simple dict[str, ...]
     # as input -> which seems like a mypy bug.
     IndexIdentifierType | str,
-    ColumnConfig | None | str,
+    ColumnConfig | str | None,
 ]
 
 
@@ -499,7 +501,7 @@ def apply_data_specific_configs(
     # Pandas adds a range index as default to all datastructures
     # but for most of the non-pandas data objects it is unnecessary
     # to show this index to the user. Therefore, we will hide it as default.
-    if data_format in [
+    if data_format in {
         DataFormat.SET_OF_VALUES,
         DataFormat.TUPLE_OF_VALUES,
         DataFormat.LIST_OF_VALUES,
@@ -516,7 +518,7 @@ def apply_data_specific_configs(
         DataFormat.POLARS_LAZYFRAME,
         DataFormat.PYARROW_ARRAY,
         DataFormat.RAY_DATASET,
-    ]:
+    }:
         update_column_config(columns_config, INDEX_IDENTIFIER, {"hidden": True})
 
 
