@@ -512,7 +512,7 @@ class NumberInputMixin:
         number_format = ("%d" if int_value else "%0.2f") if format is None else format
 
         # Warn user if they format an int type as a float or vice versa.
-        if number_format in ["%d", "%u", "%i"] and float_value:
+        if number_format in {"%d", "%u", "%i"} and float_value:
             import streamlit as st
 
             st.warning(
