@@ -54,7 +54,7 @@ def data_frame_demo() -> None:
                     color="Region:N",
                 )
             )
-            st.altair_chart(chart, use_container_width=True)
+            st.altair_chart(chart, width="stretch")
     except URLError as e:
         st.error(f"This demo requires internet access. Connection error: {e.reason}")
 
