@@ -209,8 +209,8 @@ def to_snake_case(camel_case_str: str) -> str:
         BazBang -> baz_bang
 
     """
-    s1 = re.sub("(.)([A-Z][a-z]+)", r"\1_\2", camel_case_str)
-    return re.sub("([a-z0-9])([A-Z])", r"\1_\2", s1).lower()
+    s1 = re.sub(r"(.)([A-Z][a-z]+)", r"\1_\2", camel_case_str)
+    return re.sub(r"([a-z0-9])([A-Z])", r"\1_\2", s1).lower()
 
 
 AnyNumber: TypeAlias = Union[
