@@ -90,8 +90,6 @@ T = TypeVar("T")
 class InitialValue:
     """Used to represent the initial value of a widget."""
 
-    pass
-
 
 # TODO: This class serves as a fallback option for elements that have not
 # been implemented yet, as well as providing implementations of some
@@ -515,7 +513,7 @@ DateValue: TypeAlias = SingleDateValue | Sequence[SingleDateValue] | None
 class DateInput(Widget):
     """A representation of ``st.date_input``."""
 
-    _value: DateValue | None | InitialValue
+    _value: DateValue | InitialValue | None
     proto: DateInputProto = field(repr=False)
     label: str
     min: date
@@ -884,7 +882,7 @@ Number: TypeAlias = int | float
 class NumberInput(Widget):
     """A representation of ``st.number_input``."""
 
-    _value: Number | None | InitialValue
+    _value: Number | InitialValue | None
     proto: NumberInputProto = field(repr=False)
     label: str
     min: Number | None
@@ -945,7 +943,7 @@ class NumberInput(Widget):
 class Radio(Widget, Generic[T]):
     """A representation of ``st.radio``."""
 
-    _value: T | None | InitialValue
+    _value: T | InitialValue | None
 
     proto: RadioProto = field(repr=False)
     label: str
@@ -995,8 +993,8 @@ class Radio(Widget, Generic[T]):
         """
         ws = WidgetState()
         ws.id = self.id
-        if self.index is not None:
-            ws.int_value = self.index
+        if self.index is not None and len(self.options) > 0:
+            ws.string_value = self.options[self.index]
         return ws
 
 
@@ -1004,7 +1002,7 @@ class Radio(Widget, Generic[T]):
 class Selectbox(Widget, Generic[T]):
     """A representation of ``st.selectbox``."""
 
-    _value: T | None | InitialValue
+    _value: T | InitialValue | None
 
     proto: SelectboxProto = field(repr=False)
     label: str
@@ -1096,18 +1094,33 @@ class SelectSlider(Widget, Generic[T]):
 
     @property
     def _widget_state(self) -> WidgetState:
-        serde = SelectSliderSerde(self.options, [], False)
+        # Build formatted options mapping
+        format_func = self.format_func
+        formatted_option_to_index = {
+            format_func(opt): idx for idx, opt in enumerate(self.options)
+        }
+
+        # Determine if this is a range value
+        is_range = isinstance(self.value, (list, tuple)) and len(self.value) == 2
+
+        serde = SelectSliderSerde(
+            self.options,
+            formatted_option_to_index=formatted_option_to_index,
+            default_indices=[0] if not is_range else [0, len(self.options) - 1],
+            format_func=format_func,
+        )
+
         try:
-            v = serde.serialize(self.format_func(self.value))
-        except (ValueError, TypeError):
-            try:
-                v = serde.serialize([self.format_func(val) for val in self.value])  # type: ignore
-            except:  # noqa: E722
-                raise ValueError(f"Could not find index for {self.value}")
+            if is_range:
+                v = serde.serialize(tuple(self.value))  # type: ignore
+            else:
+                v = serde.serialize(self.value)  # type: ignore
+        except (ValueError, TypeError) as e:
+            raise ValueError(f"Could not serialize value {self.value}") from e
 
         ws = WidgetState()
         ws.id = self.id
-        ws.double_array_value.data[:] = v
+        ws.string_array_value.data[:] = v
         return ws
 
     @property
@@ -1224,7 +1237,7 @@ class Text(Element):
 class TextArea(Widget):
     """A representation of ``st.text_area``."""
 
-    _value: str | None | InitialValue
+    _value: str | InitialValue | None
 
     proto: TextAreaProto = field(repr=False)
     label: str
@@ -1276,7 +1289,7 @@ class TextArea(Widget):
 class TextInput(Widget):
     """A representation of ``st.text_input``."""
 
-    _value: str | None | InitialValue
+    _value: str | InitialValue | None
     proto: TextInputProto = field(repr=False)
     label: str
     max_chars: int
@@ -1332,7 +1345,7 @@ DateTimeWidgetValue: TypeAlias = datetime
 class TimeInput(Widget):
     """A representation of ``st.time_input``."""
 
-    _value: TimeValue | None | InitialValue
+    _value: TimeValue | InitialValue | None
     proto: TimeInputProto = field(repr=False)
     label: str
     step: int
@@ -1389,7 +1402,7 @@ class TimeInput(Widget):
 class DateTimeInput(Widget):
     """A representation of ``st.datetime_input``."""
 
-    _value: DateTimeWidgetValue | None | InitialValue
+    _value: DateTimeWidgetValue | InitialValue | None
     proto: DateTimeInputProto = field(repr=False)
     label: str
     format: str
