@@ -30,10 +30,6 @@ from streamlit.auth_util import (
     is_authlib_installed,
     validate_auth_credentials,
 )
-from streamlit.deprecation_util import (
-    make_deprecated_name_warning,
-    show_deprecation_warning,
-)
 from streamlit.errors import StreamlitAPIException, StreamlitAuthError
 from streamlit.proto.ForwardMsg_pb2 import ForwardMsg
 from streamlit.runtime.metrics_util import gather_metrics
@@ -652,7 +648,7 @@ class UserInfoProxy(Mapping[str, str | bool | TokensProxy | None]):
         }
     """
 
-    def __getitem__(self, key: str) -> str | bool | None | TokensProxy:
+    def __getitem__(self, key: str) -> str | bool | TokensProxy | None:
         if key == "tokens":
             return self.tokens
         try:
@@ -660,7 +656,7 @@ class UserInfoProxy(Mapping[str, str | bool | TokensProxy | None]):
         except KeyError:
             raise KeyError(f'st.user has no key "{key}".')
 
-    def __getattr__(self, key: str) -> str | bool | None | TokensProxy:
+    def __getattr__(self, key: str) -> str | bool | TokensProxy | None:
         if key == "tokens":
             return self.tokens
         try:
@@ -701,38 +697,3 @@ class UserInfoProxy(Mapping[str, str | bool | TokensProxy | None]):
         """Access exposed tokens via a dict-like object."""
         user_info = _get_user_info()
         return TokensProxy(cast("dict[str, str]", user_info.get("tokens", {})))
-
-
-has_shown_experimental_user_warning = False
-
-
-def maybe_show_deprecated_user_warning() -> None:
-    """Show a deprecation warning for the experimental_user alias."""
-    global has_shown_experimental_user_warning  # noqa: PLW0603
-
-    if not has_shown_experimental_user_warning:
-        has_shown_experimental_user_warning = True
-        show_deprecation_warning(
-            make_deprecated_name_warning(
-                "experimental_user",
-                "user",
-                "2025-11-06",
-            )
-        )
-
-
-class DeprecatedUserInfoProxy(UserInfoProxy):
-    """
-    A deprecated alias for UserInfoProxy.
-
-    This class is deprecated and will be removed in a future version of
-    Streamlit.
-    """
-
-    def __getattribute__(self, name: str) -> Any:
-        maybe_show_deprecated_user_warning()
-        return super().__getattribute__(name)
-
-    def __getitem__(self, key: str) -> Any:
-        maybe_show_deprecated_user_warning()
-        return super().__getitem__(key)
