@@ -21,6 +21,7 @@ from typing import Final
 import tornado.web
 
 from streamlit.logger import get_logger
+from streamlit.path_security import is_unsafe_path_pattern
 
 _LOGGER: Final = get_logger(__name__)
 
@@ -53,6 +54,14 @@ class AppStaticFileHandler(tornado.web.StaticFileHandler):
     def initialize(self, path: str, default_filename: str | None = None) -> None:
         super().initialize(path, default_filename)
 
+    @classmethod
+    def get_absolute_path(cls, root: str, path: str) -> str:
+        # SECURITY: Validate path pattern BEFORE any filesystem operations.
+        # See is_unsafe_path_pattern() docstring for details.
+        if is_unsafe_path_pattern(path):
+            raise tornado.web.HTTPError(400, "Bad Request")
+        return super().get_absolute_path(root, path)
+
     def validate_absolute_path(self, root: str, absolute_path: str) -> str | None:
         full_path = os.path.abspath(absolute_path)
 
